@@ -1,6 +1,6 @@
 
 /*************************************************************************
- * Copyright (C) 2007-2012 Ruben Pollan Bella <meskio@sindominio.net>    *
+ * Copyright (C) 2007-2015 Ruben Pollan Bella <meskio@sindominio.net>    *
  *                                                                       *
  *  This file is part of TuDu.                                           *
  *                                                                       *
@@ -32,10 +32,11 @@ enum context_type {
 	C_THEME
 };
 
-Config::Config()
+Config::Config():
+	key_comb(NULL), collapse(false), hide_done(false), hide_percent(false),
+	visual_tree(false), bold_parent(true), loop_move(false),
+	days_warn_deadline(7), us_dates(false), old_sched(true)
 {
-	collapse = false;
-	hide_done = false;
 	category_length = DEFAULT_CATEGORY_LENGTH;
 }
 
@@ -198,8 +199,6 @@ void Config::insertKeyMap(key_map& k, wstring action, wstring keys)
 
 bool Config::getAction(wchar_t key, wstring& action)
 {
-	static key_map* key_comb = NULL;
-
 	if (key_comb)
 	{
 		if (key_comb->count(key) == 1)
@@ -247,6 +246,11 @@ bool Config::getAction(wchar_t key, wstring& action)
 	return false;
 }
 
+void Config::clearKeys()
+{
+	key_comb=NULL;
+}
+
 void Config::getActionList(action_list& list)
 {
 	list = action_keys;
