@@ -1,6 +1,6 @@
 
 /**************************************************************************
- * Copyright (C) 2007-2012 Ruben Pollan Bella <meskio@sindominio.net>     *
+ * Copyright (C) 2007-2015 Ruben Pollan Bella <meskio@sindominio.net>     *
  *                                                                        *
  *  This file is part of TuDu.                                            *
  *                                                                        *
@@ -89,6 +89,7 @@ public:
 
 	bool load(const char* path);
 	bool getAction(wchar_t key, wstring& action);
+	void clearKeys();
 	void getActionList(action_list& list);
 	bool getCollapse();
 	bool& getHideDone();
@@ -125,15 +126,16 @@ private:
 	} color_pair_t;
 
 	key_map tree_keys;
+	key_map* key_comb;
 	action_list action_keys;
 	bool collapse;
 	bool hide_done;
 	bool hide_percent;
 	bool visual_tree;
 	bool bold_parent;
+	bool loop_move;
 	int  days_warn_deadline;
 	bool us_dates;
-	bool loop_move;
 	bool old_sched;
 	wstring tudu_file;
 	wstring sort_order;
