@@ -1,6 +1,6 @@
 
 /**************************************************************************
- * Copyright (C) 2007-2012 Ruben Pollan Bella <meskio@sindominio.net>     *
+ * Copyright (C) 2007-2015 Ruben Pollan Bella <meskio@sindominio.net>     *
  *                                                                        *
  *  This file is part of TuDu.                                            *
  *                                                                        *
@@ -40,7 +40,7 @@ void Sched::add(pToDo todo)
 	for (i = sched.begin(); (i != sched.end()) && ((*i)->sched() < todo->sched()); i++);
 	if (todo->schedPosition() == 0)
 	{
-		if ((*i)->sched() == todo->sched())
+		if ((i != sched.end()) && ((*i)->sched() == todo->sched()))
 		{
 			for (; ((*i)->sched() == todo->sched()); i++);
 			i--;
@@ -48,7 +48,9 @@ void Sched::add(pToDo todo)
 			i++;
 		}
 		else
+		{
 			todo->schedPosition() = 1;
+		}
 	}
 	else
 	{
