@@ -1,6 +1,6 @@
 
 /**************************************************************************
- * Copyright (C) 2007-2012 Ruben Pollan Bella <meskio@sindominio.net>     *
+ * Copyright (C) 2007-2015 Ruben Pollan Bella <meskio@sindominio.net>     *
  *                                                                        *
  *  This file is part of TuDu.                                            *
  *                                                                        *
@@ -37,14 +37,14 @@ extern int errno;
 
 #define version() \
 	cout << VERSION_STR << endl; \
-	cout << "TuDu Copyright (C) 2007-2012 Ruben Pollan Bella <meskio@sindominio.net>" << endl; \
+	cout << "TuDu Copyright (C) 2007-2015 Ruben Pollan Bella <meskio@sindominio.net>" << endl; \
 	cout << "TuDu comes with ABSOLUTELY NO WARRANTY; for details type `tudu -vv'" << endl; \
 	cout << "This is free software; you are welcome to redistribute it" << endl; \
 	cout << "under certain conditions. Type `tudu -vv' for details." << endl;
 
 #define copyright() \
 	cout << VERSION_STR << endl; \
-	cout << "Copyright (C) 2007-2012 Ruben Pollan Bella <meskio@sindominio.net>" << endl << endl; \
+	cout << "Copyright (C) 2007-2015 Ruben Pollan Bella <meskio@sindominio.net>" << endl << endl; \
  	cout << "TuDu is free software; you can redistribute it and/or modify" << endl; \
  	cout << "it under the terms of the GNU General Public License as published by" << endl; \
  	cout << "the Free Software Foundation; version 3 of the License." << endl << endl; \
@@ -93,12 +93,14 @@ int main(int argc, char **argv, char *env[])
 	Config config;
 	bool configErr = !config.load(CONFIG_FILE); // the error will be displayed after check args
 	strncpy(file_rc,env[i]+5,119);
-	strcat(file_rc,"/.tudurc");
+	file_rc[119] = '\0';
+	strncat(file_rc,"/.tudurc", 9);
 	config.load(file_rc);
 
 	if (config.getTuduFile() == L"") {
 		strncpy(file_xml,env[i]+5,117);
-		strcat(file_xml,"/.tudu.xml");
+		file_xml[117] = '\0';
+		strncat(file_xml,"/.tudu.xml", 10);
 	} else {
 		wcstombs(file_xml, config.getTuduFile().c_str(), 128);
 	}
@@ -111,8 +113,10 @@ int main(int argc, char **argv, char *env[])
 		if (!strncmp("-f",argv[i],2))
 		{
 			++i;
-			if (i < argc)
+			if (i < argc) {
 				strncpy(file_xml, argv[i], 127);
+				file_xml[127] = '\0';
+			}
 			else
 			{
 				usage();
@@ -129,12 +133,14 @@ int main(int argc, char **argv, char *env[])
 					int j;
 					for (j = 0; strncmp(env[j],"PWD=",4); ++j);
 					strncpy(file_rc,env[j]+4,99);
+					file_rc[99] = '\0';
 					strcat(file_rc,"/");
 					strncat(file_rc,argv[i],27);
 				}
 				else
 				{
 					strncpy(file_rc, argv[i], 127);
+					file_rc[127] = '\0';
 				}
 				config.load(file_rc);
 			}
